@@ -135,6 +135,7 @@ _short_value = {
     "0.0.0.0": "-",
     "free_ip_addr_percent": lambda x: f"{x}%",
     "cpu_utilization": lambda x: f"{x}%",
+    "AOS-CX": "cx",
 }
 
 _short_key = {
@@ -171,6 +172,7 @@ _short_key = {
     # "acknowledged": "ack",
     "acknowledged_by": "ack by",
     "acknowledged_timestamp": "ack time",
+    "aruba_part_no": "sku",
 }
 
 
@@ -495,9 +497,7 @@ def get_devices(data: Union[List[dict], dict], sort: str = None) -> Union[List[d
 
     data = utils.listify(data)
     data = sorted(data, key=lambda i: (i.get("site") or "", i.get("type") or "", i.get("name") or ""))
-    # if sort and data and sort in data[-1]:
-    #     return sorted(data, key=sort)
-    # else:
+
     return data
 
 
@@ -923,3 +923,28 @@ def get_branch_health(data: list, down: bool = False, wan_down: bool = False) ->
 
 
     return data
+
+
+def get_device_inventory(data: List[dict], sub: bool = None) -> List[dict]:
+    field_order = [
+        "device_type",
+        "model",
+        "aruba_part_no",
+        "imei",
+        "macaddr",
+        "serial",
+        "services",
+        # "tier_type"
+    ]
+    data = [
+        dict(short_value(k, d[k]) for k in field_order) for d in data
+    ]
+    data = sorted(strip_no_value(data), key=lambda i: (i["type"], i["model"]))
+
+    if sub is not None:
+        if sub:
+            data = [{k: v for k, v in d.items()} for d in data if d["services"]]
+        else:
+            data = [{k: v for k, v in d.items()} for d in data if not d["services"]]
+
+    return data
\ No newline at end of file
